--[[
Plugin that handles flashing of the screen
]]

----------------------------------
-- Create plugin

local RW = LibStub("AceAddon-3.0"):GetAddon("Raid Watch")
local plugin = RW:Plugin("AddonCommScanner")
if not plugin then return end

----------------------------------
-- Locals 

local L =  LibStub("AceLocale-3.0"):NewLocale("RW_AddonCommScanner", "enUS", true, true)
if L then
	L.PLUGIN_DESC = "This plugin will scan the addon communication done withint the raid group during combat."
	L.RESET_SETTINGS = "Reset Settings"
	L.RESET_SETTINGS_DESC = "Resets the settings back to default for this plugin"
end

L = LibStub("AceLocale-3.0"):GetLocale("RW_AddonCommScanner")
local LSM = LibStub("LibSharedMedia-3.0")

local db

local data

local defaults = {
	profile = {
		PluginEnabled = false,
	}
}

----------------------------------
-- Init

function plugin:OnRegister()
	self.db = RW.db:RegisterNamespace("AddonCommScanner", defaults)
	db = self.db.profile
	
	self.db.RegisterCallback(self, "OnProfileChanged", "Reset")
	self.db.RegisterCallback(self, "OnProfileCopied", "Reset")
	self.db.RegisterCallback(self, "OnProfileReset", "Reset")
end

function plugin:PluginEnable()
	if not db.PluginEnabled then
		self:Disable()
		return
	end
	
	data = data or {}
	
	RWW = data
	
	self:RegisterEvent("CHAT_MSG_ADDON")
end

function plugin:PluginDisable()
	data = nil
	RWW = nil
end

function plugin:Reset()
	db = self.db.profile
end

function plugin:CHAT_MSG_ADDON(event, prefix, msg, dist, sender)
	data[dist] = data[dist] or {}
	data[dist][sender] = data[dist][sender] or {}
	data[dist][sender][prefix] = data[dist][sender][prefix] or {}
	tinsert(data[dist][sender][prefix], msg)
end

-------------------------------------
-- Options

function plugin:GetOptions()
	self.category = "Misc Plugins"
	local icon = [[Interface\Icons\Ability_Rogue_MasterOfSubtlety]]

	local function get(info)
		return db[info[#info]]
	end
	
	local function set(info, value, g, b)
		if g then
			local r, g, b = value, g, b
			local c = db[info[#info]]
			c[1], c[2], c[3] = r, g, b
		else
			db[info[#info]] = value
		end
	end
	
	local options = {
		type = "group",
		name = "Addon Comms Scanner",
		icon = icon,
		set = set,
		get = get,
		args  = {
			image = {
				type = "description",
				name = L.PLUGIN_DESC,
				image = icon,
				width = "full",
				imageWidth = 50,
				imageHeight = 50,
				imageCoords = {0.1,0.9,0.1,0.9},
				order = 1,
			},
			enabled = {
				type = "toggle",
				name = "Enabled",
				set = function(info, value) 
					db.PluginEnabled = value
					if not db.PluginEnabled then
						self:Disable()
					else
						self:Enable()
					end
				end,
				get = function(info) return db.PluginEnabled end,
				order = 2,
			},
			headingBreak = {
				type = "header",
				name = "",
				order = 3,
			},
			Reset = {
				type = "execute",
				name = L.RESET_SETTINGS,
				desc = L.RESET_SETTINGS_DESC,
				confirm = true,
				func = function() self.db:ResetProfile() end,
				order = 99,
			},
		}
	}
	--return "Plugins", "Misc", options
	
	
	return "Plugins", "Test", plugin.GetGUI, icon
end

function plugin:GetGUI()
	self = self or plugin
	local AceGUI = LibStub("AceGUI-3.0")
	
	local scroll = AceGUI:Create("ScrollFrame")
	scroll:SetLayout("Flow")
	
	local button = AceGUI:Create("Button")
	button:SetText("test")
	scroll:AddChild(button)

	return scroll
end